@@ -49,17 +49,7 @@ def read_str(p_banner, strdef = "", passwd = 0):
     #screen.clrtoeol()
     key = screen.getch()
     if (
-         (key >= ord("0") and key <= ord("9"))
-      or (key >= ord("A") and key <= ord("Z"))
-      or (key >= ord("a") and key <= ord("z"))
-      or  key == ord("=")  or  key == ord(" ")
-      or  key == ord(">")  or  key == ord("<")
-      or  key == ord("_")  or  key == ord("-")
-      or  key == ord("%")  or  key == ord("*")
-      or  key == ord("!")  or  key == ord("$")
-      or  key == ord(",")  or  key == ord(".")
-      or  key == ord('"')  or  key == ord("'")
-      or  key == ord("(")  or  key == ord(")")
+         (key >= ord(" ") and key <= ord("~"))
       or (key == 127 or key == 263 or key == 8)
     ):
       strlen = len(vstr)
