@@ -20,25 +20,29 @@ def get_conn():
   global connstr
   return(connstr)
 
-def qry2dict(qry, qry_params=(),dbfile=None,con=None):
+def qry2dict(con, qry, qry_params=(),dbfile=None):
   res={}
   try:
     dt = str(datetime.now())
     #msg_log(dt+" "+qry+"\n") 
-    if dbfile is None:
+    #if dbfile is None:
+    if con is None:
       con = sqlite3.connect(get_conn())
     cur = con.cursor()
     cur.execute(qry,qry_params)
-    con.commit()
-    data = cur.fetchall()
+    try: 
+      data = cur.fetchall()
+    except:
+      con.commit()
+      return(con,res,cols)
     cols=[]
     if cur.description is not None:
       for col in cur.description:
         cols.append(col[0])
-      if dbfile is not None:
-        con.commit()
-      else:
-        con.close()
+      #if dbfile is not None:
+      con.commit()
+      #else:
+      #  con.close()
       if len(data)>0:
         i=0
         for col in cols:
@@ -46,7 +50,7 @@ def qry2dict(qry, qry_params=(),dbfile=None,con=None):
           for row in data:
             res[col].append(row[i])
           i+=1
-    return (res,cols)
+    return(con,res,cols)
   except Exception as e:
     #con.close()
     #traceback.print_exc(file=sys.stdout)
